Failure class abstract

Modelo de fallo utilizado por las funciones que devuelven Either<Failure, T>.

Failure encapsula un mensaje (obligatorio) y un código opcional.

Implementers

Constructors

Failure(String message, {int? code})
const

Properties

code int?
Código numérico opcional relacionado con el fallo (por ejemplo, HTTP code).
final
hashCode int
The hash code for this object.
no setterinherited
message String
Mensaje descriptivo del fallo.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited