UnknownFailure class

Fallo desconocido o no tipificado.

Inheritance

Constructors

UnknownFailure(String message)
const

Properties

code int?
Código numérico opcional relacionado con el fallo (por ejemplo, HTTP code).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Mensaje descriptivo del fallo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited