CartModel class

Constructors

CartModel({required int id, required int userId, required DateTime date, required List<CartProductModel> products})
const

Properties

date DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
products List<CartProductModel>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited