AddressModel class

Constructors

AddressModel({required GeolocationModel geolocation, required String city, required String street, required int number, required String zipcode})

Properties

city String
getter/setter pair
geolocation GeolocationModel
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
number int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
street String
getter/setter pair
zipcode String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited