FackeStoreApiClient class

Clase de conveniencia que expone notifiers configurados por módulos.

Esta clase ofrece métodos estáticos para obtener los Notifier usados en la aplicación de ejemplo (productos, carritos y usuarios). Sirve como punto de entrada simple para clientes que quieran integrar estos módulos sin conocer la configuración interna de los contenedores.

Constructors

FackeStoreApiClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

cartsNotifier() CartsNotifier
Devuelve el CartsNotifier configurado en el módulo de carritos.
productsNotifier() ProductsNotifier
Devuelve el ProductsNotifier configurado en el módulo de productos.
usersNotifier() UsersNotifier
Devuelve el UsersNotifier configurado en el módulo de usuarios.