CartsNotifier class
Constructors
- CartsNotifier({required GetCartsUseCase getCarts})
Properties
-
debugState
→ AsyncValue<
List< Cart> > -
A development-only way to access
stateoutside ofStateNotifier.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
If a listener has been added using
addListenerand hasn't been removed yet.no setterinherited - mounted → bool
-
Whether
disposewas called or not.no setterinherited - onError ↔ ErrorListener?
-
A callback for error reporting if one of the listeners added with
addListenerthrows.getter/setter pairinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
↔ AsyncValue<
List< Cart> > -
The current "state" of this
StateNotifier.getter/setter pairinherited -
stream
→ Stream<
AsyncValue< List< >Cart> > -
A broadcast stream representation of a
StateNotifier.no setterinherited
Methods
-
addListener(
Listener< AsyncValue< listener, {bool fireImmediately = true}) → RemoveListenerList< >Cart> > -
Subscribes to this object.
inherited
-
dispose(
) → void -
Frees all the resources associated with this object.
inherited
-
loadAllCarts(
) → Future< List< Cart> ?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
AsyncValue< List< old, AsyncValue<Cart> >List< current) → boolCart> > -
Whether to notify listeners or not when
statechangesinherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited