AppException class abstract
Excepciones específicas de la aplicación.
Estas clases representan excepciones de más bajo nivel que pueden
ser transformadas a Failure en capas superiores cuando sea necesario.
- Implemented types
- Implementers
Constructors
- AppException(String message, {int? code})
-
const
Properties
- code → int?
-
Código numérico opcional asociado a la excepción (por ejemplo, HTTP code).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Mensaje descriptivo de la excepción.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited